#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rere
version:              0.2.0.2
visibility:           public
id:                   rere-0.2.0.2-5QkdE877DD9DD4KHMT4Ind
key:                  rere-0.2.0.2-5QkdE877DD9DD4KHMT4Ind
license:              BSD-3-Clause
maintainer:           Artem Pelenitsyn <a@pelenitsyn.top>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  e95f69282d965bd72b1caa92b17ad451
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.6.6/site-local/rere-0.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rere-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rere-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rere
hs-libraries:         HSrere-0.2.0.2-5QkdE877DD9DD4KHMT4Ind
depends:
    QuickCheck-2.15.0.1-7bkIiMcYWfPHJxyqEJPybZ base-4.18.2.1
    containers-0.6.7 fin-0.3.2-KZgavFuwuhH1cdMiDu5tD3 parsec-3.1.16.1
    transformers-0.6.1.0 vec-0.5.1.1-KB3g1KGERP88g79XVueYk

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

